#!/bin/bash

# Define menu options
amenu="a.  List directory"                            ;
bmenu="b.  Print working directory "                  ; 
cmenu="c.  Show disk usage for files in this folder"  ; 
dmenu="d.  Show logged users "                        ;


# Define a function for invalid menu picks
# The function loads an error message into a variable
badchoice () { MSG="Invalid Selection ... Please Try Again" ; }

apick () { ls -l | more ; echo Press Enter ; read DUMMY ; }
bpick () { pwd ;          echo Press Enter ; read DUMMY ; }
cpick () { du -hs * ;     echo Press Enter ; read DUMMY ; }
dpick () { who ;          echo Press Enter ; read DUMMY ; }


# This function displays the menu.
# The routine clears the screen, 
# then echoes the menu prompts

themenu () {
	# clear the screen
	clear
	echo `date`
	echo
	echo "   Please Select:"
	echo
	echo "   " $amenu
	echo "   " $bmenu
	echo "   " $cmenu
	echo "   " $dmenu
	echo "    x. Exit"
	echo
	echo $MSG
	echo
	echo Select by pressing the letter and then ENTER ;	
}

#------------------------------------------------------
# MAIN LOGIC
#------------------------------------------------------
# Everything up to this point has been to define
# variables or functions.
# The program actually starts running here.

# Clear out the error message variable
MSG=

# Repeat the menu over and over
# Steps are:
# 1. Display the menu
# 2. 'read' a line of input from the keyboard
# 3. Clear the error message
# 4. Check the answer for a or A or b or B etc. and dispatch
#    to the appropriate program or function or exit
# 5. If the entry was invalid call the badchoice () function
#    to initialize MSG to an error message
# 6. This error message is used when setting up the menu
#    for a menu pick that is valid but has no command
#    associated with it.

while  true
do
	# 1. display the menu
	themenu
 
	# 2. read a line of input from the keyboard
	read answer
 
	# 3. Clear any error message
	MSG=

	# 4. Execute one of the defined functions based on the
	#    letter entered by the user 
	case $answer in
		a|A) apick;;
		b|B) bpick;;
		c|C) cpick;;
		d|D) dpick;;
 
		# If the user selects x then break out of this loop
		x|X) break;;
  
		# 6. If the entry was invalid call the badchoice function
		#    to initialize MSG to an error message
		*) badchoice;;
	esac

	# Do it again until the user enters x.
done
